==> cloud-3.0.0-rc1.tar.gz: cloud/modules/cloud_service_providers/vmware/src/Service/VmwareServiceInterface.php <==
<?php

namespace Drupal\vmware\Service;

/**
 * VMware service interface.
 */
interface VmwareServiceInterface {

  /**
   * Set the cloud context.
   *
   * @param string $cloud_context
   *   Cloud context string.
   */
  public function setCloudContext($cloud_context);

  /**
   * Set credentials.
   *
   * @param array $credentials
   *   Credentials.
   */
  public function setCredentials(array $credentials);

  /**
   * Login to an VMware server.
   */
  public function login();

  /**
   * Describe VMs.
   *
   * @param array $params
   *   Parameters array to send to API.
   *
   * @return mixed
   *   An array of results or NULL if there is an error.
   */
  public function describeVms(array $params = []);

  /**
   * Start VM.
   *
   * @param array $params
   *   Parameters array to send to API.
   */
  public function startVm(array $params = []);

  /**
   * Stop VM.
   *
   * @param array $params
   *   Parameters array to send to API.
   */
  public function stopVm(array $params = []);

  /**
   * Reboot VM.
   *
   * @param array $params
   *   Parameters array to send to API.
   */
  public function rebootVm(array $params = []);

  /**
   * Suspend VM.
   *
   * @param array $params
   *   Parameters array to send to API.
   */
  public function suspendVm(array $params = []);

  /**
   * Delete VM.
   *
   * @param array $params
   *   Parameters array to send to API.
   */
  public function deleteVm(array $params = []);

  /**
   * Create VM.
   *
   * @param array $params
   *   Parameters array to send to API.
   */
  public function createVm(array $params = []);

  /**
   * Update the VMs.
   *
   * Delete old VM entities, query the api for updated entities and store
   * them as VM entities.
   *
   * @param array $params
   *   Optional parameters array.
   * @param bool $clear
   *   TRUE to clear stale entities.
   *
   * @return array
   *   The response of API.
   */
  public function updateVms(array $params = [], $clear = TRUE);

  /**
   * Update the VM memory.
   *
   * @param string $vm_id
   *   The VM's ID.
   * @param int $memory_size
   *   The memory size.
   *
   * @return array
   *   The response of API.
   */
  public function updateVmMemory($vm_id, $memory_size);

  /**
   * Describe the folders.
   *
   * @param array $params
   *   Parameters array to send to API.
   *
   * @return mixed
   *   An array of results or NULL if there is an error.
   */
  public function describeFolders(array $params = []);

  /**
   * Describe the datastores.
   *
   * @param array $params
   *   Parameters array to send to API.
   *
   * @return mixed
   *   An array of results or NULL if there is an error.
   */
  public function describeDatastores(array $params = []);

  /**
   * Update the Hosts.
   *
   * Delete old VM entities, query the api for updated entities and store
   * them as Host entities.
   *
   * @param array $params
   *   Optional parameters array.
   * @param bool $clear
   *   TRUE to clear stale entities.
   *
   * @return array
   *   The response of API.
   */
  public function updateHosts(array $params = [], $clear = TRUE);

  /**
   * Describe the hosts.
   *
   * @param array $params
   *   Parameters array to send to API.
   *
   * @return mixed
   *   An array of results or NULL if there is an error.
   */
  public function describeHosts(array $params = []);

  /**
   * Describe the resource pools.
   *
   * @param array $params
   *   Parameters array to send to API.
   *
   * @return mixed
   *   An array of results or NULL if there is an error.
   */
  public function describeResourcePools(array $params = []);

}

==> cloud-3.0.3.tar.gz: cloud/modules/cloud_service_providers/vmware/src/Service/VmwareServiceInterface.php <==
<?php

namespace Drupal\vmware\Service;

/**
 * VMware service interface.
 */
interface VmwareServiceInterface {

  /**
   * Set the cloud context.
   *
   * @param string $cloud_context
   *   Cloud context string.
   */
  public function setCloudContext($cloud_context): void;

  /**
   * Set credentials.
   *
   * @param array $credentials
   *   Credentials.
   */
  public function setCredentials(array $credentials): void;

  /**
   * Login to an VMware server.
   */
  public function login(): void;

  /**
   * Describe VMs.
   *
   * @param array $params
   *   Parameters array to send to API.
   *
   * @return mixed
   *   An array of results or NULL if there is an error.
   */
  public function describeVms(array $params = []): array;

  /**
   * Start VM.
   *
   * @param array $params
   *   Parameters array to send to API.
   */
  public function startVm(array $params = []): array;

  /**
   * Stop VM.
   *
   * @param array $params
   *   Parameters array to send to API.
   */
  public function stopVm(array $params = []): array;

  /**
   * Reboot VM.
   *
   * @param array $params
   *   Parameters array to send to API.
   */
  public function rebootVm(array $params = []): array;

  /**
   * Suspend VM.
   *
   * @param array $params
   *   Parameters array to send to API.
   */
  public function suspendVm(array $params = []): array;

  /**
   * Delete VM.
   *
   * @param array $params
   *   Parameters array to send to API.
   */
  public function deleteVm(array $params = []): array;

  /**
   * Create VM.
   *
   * @param array $params
   *   Parameters array to send to API.
   */
  public function createVm(array $params = []): array;

  /**
   * Update the VMs.
   *
   * Delete old VM entities, query the api for updated entities and store
   * them as VM entities.
   *
   * @param array $params
   *   Optional parameters array.
   * @param bool $clear
   *   TRUE to clear stale entities.
   *
   * @return array
   *   The response of API.
   */
  public function updateVms(array $params = [], $clear = TRUE): bool;

  /**
   * Update the VM memory.
   *
   * @param string $vm_id
   *   The VM's ID.
   * @param int $memory_size
   *   The memory size.
   *
   * @return array
   *   The response of API.
   */
  public function updateVmMemory($vm_id, $memory_size): array;

  /**
   * Describe the folders.
   *
   * @param array $params
   *   Parameters array to send to API.
   *
   * @return mixed
   *   An array of results or NULL if there is an error.
   */
  public function describeFolders(array $params = []): array;

  /**
   * Describe the datastores.
   *
   * @param array $params
   *   Parameters array to send to API.
   *
   * @return mixed
   *   An array of results or NULL if there is an error.
   */
  public function describeDatastores(array $params = []): array;

  /**
   * Update the Hosts.
   *
   * Delete old VM entities, query the api for updated entities and store
   * them as Host entities.
   *
   * @param array $params
   *   Optional parameters array.
   * @param bool $clear
   *   TRUE to clear stale entities.
   *
   * @return array
   *   The response of API.
   */
  public function updateHosts(array $params = [], $clear = TRUE): bool;

  /**
   * Describe the hosts.
   *
   * @param array $params
   *   Parameters array to send to API.
   *
   * @return mixed
   *   An array of results or NULL if there is an error.
   */
  public function describeHosts(array $params = []): array;

  /**
   * Describe the resource pools.
   *
   * @param array $params
   *   Parameters array to send to API.
   *
   * @return mixed
   *   An array of results or NULL if there is an error.
   */
  public function describeResourcePools(array $params = []): array;

}
